@@ -1,11 +1,11 @@
-# Copyright (C) 2021  The Software Heritage developers
+# Copyright (C) 2021-2022  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
-from django.conf.urls import url
 from django.contrib.auth.views import LogoutView
 from django.http import HttpResponse
+from django.urls import re_path as url
 from rest_framework.decorators import api_view
 from rest_framework.response import Response
 
